TODO List
=========


.. todolist::



Improve reference search to see if every author on the pub has the pub associated with them on ORCID.

Let the authors_file for add_authors be an excel file.

Add recipes for common use cases such as a trainee project to the documentation.

Add PMCID and grants to pymed package.

Add expanded search to orcid package or look for more up to date package to use. Expanded search was added to ORCID's API with 3.0 release. orcid package appears to be 2.0 only.

